searchData={"content_type":"text/markdown","items":[{"doc":"Sham is a mock HTTP(S) server useful for testing HTTP(S) clients.","ref":"Sham.html","title":"Sham","type":"module"},{"doc":"Expect at least one call to the Sham instance using any method and at any path.","ref":"Sham.html#expect/2","title":"Sham.expect/2","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.expect(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n    iex> ShamTest.post(\"http://localhost:#{sham.port}/other\", \"foo=bar\")\n    {:ok, 200, \"Hello\"}\n\n    sham = Sham.start()\n    Sham.expect(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    ** (ExUnit.AssertionError) No HTTP request was received by Sham\n\nIf no request is sent to the sham port, an assertion error will be raised.","ref":"Sham.html#expect/2-examples","title":"Examples - Sham.expect/2","type":"function"},{"doc":"Expect at least one call to the Sham instance using the given method and path.\n\n- `method` - The HTTP method to expect. Should be one of `\"GET\"`, `\"POST\"`, `\"PUT\"`, `\"PATCH\"`, `\"DELETE\"`, `\"HEAD\"`, or `\"OPTIONS\"` or (Anything Plug supports).\n- `path` - The path to expect","ref":"Sham.html#expect/4","title":"Sham.expect/4","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.expect(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n\n    # Sending a request that does not match an expectation will result in an assertion error\n    ShamTest.post(\"http://localhost:#{sham.port}/other\", \"foo=bar\")\n    {:ok, 500, \"Unexpected request to Sham: POST /other\"}\n    ** (ExUnit.AssertionError) Unexpected request to Sham: POST /other\n\nIf no request is sent to the sham port using the given method and path, an assertion error will be raised.","ref":"Sham.html#expect/4-examples","title":"Examples - Sham.expect/4","type":"function"},{"doc":"Expect at most one call to the Sham instance using any method and at any path.\n\nYou can stack multiple calls to `expect_once/4` to expect multiple requests.","ref":"Sham.html#expect_once/2","title":"Sham.expect_once/2","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.expect_once(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n\n    iex> sham = Sham.start()\n    iex> Sham.expect_once(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n    iex> Sham.expect_once(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"World\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"World\"}\n\n    # Sending a more than one request will result in an assertion error\n    ShamTest.post(\"http://localhost:#{sham.port}/other\", \"foo=bar\")\n    {:ok, 500, \"Exceeded expected requests to Sham: POST /other\"}\n    ** (ExUnit.AssertionError) Exceeded expected requests to Sham: POST /other\n\nIf a request is sent to the sham port using a different method or path, an assertion error will be raised.","ref":"Sham.html#expect_once/2-examples","title":"Examples - Sham.expect_once/2","type":"function"},{"doc":"Expect at most one call to the Sham instance using the given method and path.\n\nYou can stack multiple calls to `expect_once/4` to expect multiple requests.\n\n- `method` - The HTTP method to expect. Should be one of `\"GET\"`, `\"POST\"`, `\"PUT\"`, `\"PATCH\"`, `\"DELETE\"`, `\"HEAD\"`, or `\"OPTIONS\"` or (Anything Plug supports).\n- `path` - The path to expect","ref":"Sham.html#expect_once/4","title":"Sham.expect_once/4","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.expect_once(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n\n    iex> sham = Sham.start()\n    iex> Sham.expect_once(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n    iex> Sham.expect_once(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"World\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"World\"}\n\n    # Sending a more than one request with the same method and path will result in an assertion error\n    ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 500, \"Exceeded expected requests to Sham: GET /hello\"}\n    ** (ExUnit.AssertionError) Exceeded expected requests to Sham: GET /hello\n\nIf no request is sent to the sham port using the given method and path, an assertion error will be raised.","ref":"Sham.html#expect_once/4-examples","title":"Examples - Sham.expect_once/4","type":"function"},{"doc":"Forces the Sham instance to pass regardless of whether a valid request was sent to the sham port or not.","ref":"Sham.html#pass/1","title":"Sham.pass/1","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.expect(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.post(\"http://localhost:#{sham.port}/other\", \"foo=bar\")\n    {:ok, 500, \"Unexpected request to Sham: POST /other\"}\n    iex> Sham.pass(sham)\n\n    iex> sham = Sham.start()\n    iex> Sham.expect(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> Sham.pass(sham)\n\nNo assertions will be raised.","ref":"Sham.html#pass/1-examples","title":"Examples - Sham.pass/1","type":"function"},{"doc":"Starts a new Sham instance.","ref":"Sham.html#start/1","title":"Sham.start/1","type":"function"},{"doc":"* `:ssl` - Whether to start the server in SSL mode. Defaults to `false`.\n* `:keyfile` - The path to an SSL keyfile. Defaults to an internal self-signed key.\n* `:certfile` - The path to an SSL certfile. Defaults to an internal self-signed certificate.","ref":"Sham.html#start/1-options","title":"Options - Sham.start/1","type":"function"},{"doc":"sham = Sham.start()\n    Sham.expect(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n\n    sham = Sham.start(ssl: true)\n    Sham.expect(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)","ref":"Sham.html#start/1-examples","title":"Examples - Sham.start/1","type":"function"},{"doc":"Provide a callback to handle any requests to the Sham instance without assertions.\n\nNo exceptions will be raised if no requests are sent to the sham port.","ref":"Sham.html#stub/2","title":"Sham.stub/2","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.stub(sham, fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n    iex> ShamTest.post(\"http://localhost:#{sham.port}/other\", \"foo=bar\")\n    {:ok, 200, \"Hello\"}","ref":"Sham.html#stub/2-examples","title":"Examples - Sham.stub/2","type":"function"},{"doc":"Provide a callback to handle any requests to the Sham instance using the given method and path without assertions.\n\nNo exceptions will be raised if no requests are sent to the sham port using the given method and path.","ref":"Sham.html#stub/4","title":"Sham.stub/4","type":"function"},{"doc":"iex> sham = Sham.start()\n    iex> Sham.stub(sham, \"GET\", \"/hello\", fn conn -> Plug.Conn.send_resp(conn, 200, \"Hello\") end)\n    iex> ShamTest.get(\"http://localhost:#{sham.port}/hello\")\n    {:ok, 200, \"Hello\"}\n\n    # Sending a request with a different method and path will result in an assertion error\n    ShamTest.post(\"http://localhost:#{sham.port}/other\", \"foo=bar\")\n    {:ok, 500, \"Unexpected request to Sham: POST /other\"}\n    ** (ExUnit.AssertionError) Unexpected request to Sham: POST /other","ref":"Sham.html#stub/4-examples","title":"Examples - Sham.stub/4","type":"function"},{"doc":"","ref":"Sham.html#t:sham_opts/0","title":"Sham.sham_opts/0","type":"type"},{"doc":"","ref":"Sham.html#t:t/0","title":"Sham.t/0","type":"opaque"},{"doc":"# Sham\n\nAn Elixir mock HTTP(S) server useful for testing HTTP(S) clients.\n\n![example workflow](https://github.com/andrewtimberlake/sham/actions/workflows/main.yml/badge.svg)\n[![Hex version badge](https://img.shields.io/hexpm/v/sham.svg)](https://hex.pm/packages/sham)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/sham/)\n[![License badge](https://img.shields.io/hexpm/l/sham.svg)](https://github.com/andrewtimberlake/sham/blob/master/LICENSE)","ref":"readme.html","title":"Sham","type":"extras"},{"doc":"```elixir\n  sham = Sham.start(ssl: true, certfile: \"/path/to/cert.pem\", keyfile: \"/path/to/key.pem\")\n\n  Sham.expect(sham, \"GET\", \"/\", fn conn ->\n    Plug.Conn.resp(conn, 200, \"Hello world\")\n  end)\n\n  {:ok, 200, response_body} = HttpClient.get(\"https://localhost:#{sham.port}\")\n\n  assert response_body == \"Hello world\"\n```","ref":"readme.html#usage","title":"Usage - Sham","type":"extras"},{"doc":"The package can be installed by adding `sham` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sham, \"~> 1.0\"}\n  ]\nend\n```\n\nDocumentation is available at  .","ref":"readme.html#installation","title":"Installation - Sham","type":"extras"},{"doc":"#","ref":"readme.html#ssl","title":"SSL - Sham","type":"extras"},{"doc":"```bash\nopenssl req -x509 -nodes -days 3650 -newkey rsa:2048 -keyout priv/ssl/key.pem -out priv/ssl/cert.pem\n```","ref":"readme.html#generate-keys","title":"Generate Keys - Sham","type":"extras"},{"doc":"Thank you for using this library.\n\nIf you’d like to support me, I am available for Elixir consulting and online pair programming.\n\nI am also the founder of [Sitesure](https://sitesure.net) which provides uptime and background monitoring, notifying you immediately when your services go down.","ref":"readme.html#about","title":"About - Sham","type":"extras"}]}